==> explore-html-2.2.2.tgz: explore-html/menudata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var menudata={children:[
{text:"Main Page",url:"index.html"},
{text:"Data Types",url:"annotated.html",children:[
{text:"Data Types List",url:"annotated.html"},
{text:"Data Type Index",url:"classes.html"},
{text:"Data Fields",url:"functions.html",children:[
{text:"All",url:"functions.html",children:[
{text:"a",url:"functions.html#index_a"},
{text:"b",url:"functions.html#index_b"},
{text:"c",url:"functions.html#index_c"},
{text:"d",url:"functions.html#index_d"},
{text:"f",url:"functions.html#index_f"},
{text:"g",url:"functions.html#index_g"},
{text:"i",url:"functions.html#index_i"},
{text:"l",url:"functions.html#index_l"},
{text:"m",url:"functions.html#index_m"},
{text:"n",url:"functions.html#index_n"},
{text:"o",url:"functions.html#index_o"},
{text:"p",url:"functions.html#index_p"},
{text:"r",url:"functions.html#index_r"},
{text:"s",url:"functions.html#index_s"},
{text:"t",url:"functions.html#index_t"},
{text:"u",url:"functions.html#index_u"},
{text:"z",url:"functions.html#index_z"}]},
{text:"Variables",url:"functions_vars.html",children:[
{text:"a",url:"functions_vars.html#index_a"},
{text:"b",url:"functions_vars.html#index_b"},
{text:"c",url:"functions_vars.html#index_c"},
{text:"d",url:"functions_vars.html#index_d"},
{text:"f",url:"functions_vars.html#index_f"},
{text:"g",url:"functions_vars.html#index_g"},
{text:"i",url:"functions_vars.html#index_i"},
{text:"l",url:"functions_vars.html#index_l"},
{text:"m",url:"functions_vars.html#index_m"},
{text:"n",url:"functions_vars.html#index_n"},
{text:"o",url:"functions_vars.html#index_o"},
{text:"p",url:"functions_vars.html#index_p"},
{text:"r",url:"functions_vars.html#index_r"},
{text:"s",url:"functions_vars.html#index_s"},
{text:"t",url:"functions_vars.html#index_t"},
{text:"u",url:"functions_vars.html#index_u"},
{text:"z",url:"functions_vars.html#index_z"}]}]}]},
{text:"Files",url:"files.html",children:[
{text:"File List",url:"files.html"},
{text:"File Members",url:"globals.html",children:[
{text:"All",url:"globals.html",children:[
{text:"!",url:"globals.html#index__21"},
{text:"_",url:"globals__.html#index__5F"},
{text:"a",url:"globals_a.html#index_a"},
{text:"b",url:"globals_b.html#index_b"},
{text:"c",url:"globals_c.html#index_c"},
{text:"d",url:"globals_d.html#index_d"},
{text:"e",url:"globals_e.html#index_e"},
{text:"f",url:"globals_f.html#index_f"},
{text:"g",url:"globals_g.html#index_g"},
{text:"h",url:"globals_h.html#index_h"},
{text:"i",url:"globals_i.html#index_i"},
{text:"j",url:"globals_j.html#index_j"},
{text:"k",url:"globals_k.html#index_k"},
{text:"l",url:"globals_l.html#index_l"},
{text:"m",url:"globals_m.html#index_m"},
{text:"n",url:"globals_n.html#index_n"},
{text:"o",url:"globals_o.html#index_o"},
{text:"p",url:"globals_p.html#index_p"},
{text:"r",url:"globals_r.html#index_r"},
{text:"s",url:"globals_s.html#index_s"},
{text:"t",url:"globals_t.html#index_t"},
{text:"u",url:"globals_u.html#index_u"},
{text:"v",url:"globals_v.html#index_v"},
{text:"w",url:"globals_w.html#index_w"},
{text:"x",url:"globals_x.html#index_x"},
{text:"y",url:"globals_y.html#index_y"},
{text:"z",url:"globals_z.html#index_z"}]},
{text:"Functions/Subroutines",url:"globals_func.html",children:[
{text:"!",url:"globals_func.html#index__21"},
{text:"a",url:"globals_func_a.html#index_a"},
{text:"b",url:"globals_func_b.html#index_b"},
{text:"c",url:"globals_func_c.html#index_c"},
{text:"d",url:"globals_func_d.html#index_d"},
{text:"f",url:"globals_func_f.html#index_f"},
{text:"g",url:"globals_func_g.html#index_g"},
{text:"i",url:"globals_func_i.html#index_i"},
{text:"j",url:"globals_func_j.html#index_j"},
{text:"k",url:"globals_func_k.html#index_k"},
{text:"l",url:"globals_func_l.html#index_l"},
{text:"m",url:"globals_func_m.html#index_m"},
{text:"n",url:"globals_func_n.html#index_n"},
{text:"p",url:"globals_func_p.html#index_p"},
{text:"r",url:"globals_func_r.html#index_r"},
{text:"s",url:"globals_func_s.html#index_s"},
{text:"t",url:"globals_func_t.html#index_t"},
{text:"x",url:"globals_func_x.html#index_x"},
{text:"z",url:"globals_func_z.html#index_z"}]},
{text:"Variables",url:"globals_vars.html"},
{text:"Typedefs",url:"globals_type.html",children:[
{text:"a",url:"globals_type.html#index_a"},
{text:"b",url:"globals_type.html#index_b"},
{text:"c",url:"globals_type.html#index_c"},
{text:"f",url:"globals_type.html#index_f"},
{text:"g",url:"globals_type.html#index_g"},
{text:"h",url:"globals_type.html#index_h"},
{text:"m",url:"globals_type.html#index_m"},
{text:"s",url:"globals_type.html#index_s"},
{text:"t",url:"globals_type.html#index_t"},
{text:"v",url:"globals_type.html#index_v"}]},
{text:"Macros",url:"globals_defs.html",children:[
{text:"_",url:"globals_defs.html#index__5F"},
{text:"a",url:"globals_defs_a.html#index_a"},
{text:"b",url:"globals_defs_b.html#index_b"},
{text:"c",url:"globals_defs_c.html#index_c"},
{text:"d",url:"globals_defs_d.html#index_d"},
{text:"e",url:"globals_defs_e.html#index_e"},
{text:"f",url:"globals_defs_f.html#index_f"},
{text:"g",url:"globals_defs_g.html#index_g"},
{text:"h",url:"globals_defs_h.html#index_h"},
{text:"i",url:"globals_defs_i.html#index_i"},
{text:"l",url:"globals_defs_l.html#index_l"},
{text:"m",url:"globals_defs_m.html#index_m"},
{text:"n",url:"globals_defs_n.html#index_n"},
{text:"o",url:"globals_defs_o.html#index_o"},
{text:"p",url:"globals_defs_p.html#index_p"},
{text:"r",url:"globals_defs_r.html#index_r"},
{text:"s",url:"globals_defs_s.html#index_s"},
{text:"t",url:"globals_defs_t.html#index_t"},
{text:"u",url:"globals_defs_u.html#index_u"},
{text:"w",url:"globals_defs_w.html#index_w"},
{text:"y",url:"globals_defs_y.html#index_y"},
{text:"z",url:"globals_defs_z.html#index_z"}]}]}]}]}

==> explore-html-3.7.1.tgz: explore-html/menudata.js <==
var menudata={children:[
{text:"Main Page",url:"index.html"},
{text:"Modules",url:"modules.html"},
{text:"Data Types List",url:"annotated.html",children:[
{text:"Data Types List",url:"annotated.html"},
{text:"Data Types",url:"classes.html"},
{text:"Data Fields",url:"functions.html",children:[
{text:"All",url:"functions.html"},
{text:"Variables",url:"functions_vars.html"}]}]},
{text:"Files",url:"files.html",children:[
{text:"File List",url:"files.html"},
{text:"File Members",url:"globals.html",children:[
{text:"All",url:"globals.html",children:[
{text:"_",url:"globals.html#index__"},
{text:"a",url:"globals_a.html#index_a"},
{text:"c",url:"globals_c.html#index_c"},
{text:"d",url:"globals_d.html#index_d"},
{text:"f",url:"globals_f.html#index_f"},
{text:"g",url:"globals_g.html#index_g"},
{text:"h",url:"globals_h.html#index_h"},
{text:"i",url:"globals_i.html#index_i"},
{text:"l",url:"globals_l.html#index_l"},
{text:"m",url:"globals_m.html#index_m"},
{text:"n",url:"globals_n.html#index_n"},
{text:"p",url:"globals_p.html#index_p"},
{text:"r",url:"globals_r.html#index_r"},
{text:"s",url:"globals_s.html#index_s"},
{text:"t",url:"globals_t.html#index_t"},
{text:"u",url:"globals_u.html#index_u"},
{text:"x",url:"globals_x.html#index_x"},
{text:"z",url:"globals_z.html#index_z"}]},
{text:"Functions/Subroutines",url:"globals_func.html",children:[
{text:"_",url:"globals_func.html#index__"},
{text:"a",url:"globals_func_a.html#index_a"},
{text:"c",url:"globals_func_c.html#index_c"},
{text:"d",url:"globals_func_d.html#index_d"},
{text:"f",url:"globals_func_f.html#index_f"},
{text:"g",url:"globals_func_g.html#index_g"},
{text:"h",url:"globals_func_h.html#index_h"},
{text:"i",url:"globals_func_i.html#index_i"},
{text:"l",url:"globals_func_l.html#index_l"},
{text:"m",url:"globals_func_m.html#index_m"},
{text:"p",url:"globals_func_p.html#index_p"},
{text:"s",url:"globals_func_s.html#index_s"},
{text:"t",url:"globals_func_t.html#index_t"},
{text:"x",url:"globals_func_x.html#index_x"},
{text:"z",url:"globals_func_z.html#index_z"}]},
{text:"Variables",url:"globals_vars.html",children:[
{text:"c",url:"globals_vars.html#index_c"},
{text:"l",url:"globals_vars.html#index_l"},
{text:"r",url:"globals_vars.html#index_r"}]},
{text:"Typedefs",url:"globals_type.html"},
{text:"Enumerations",url:"globals_enum.html"},
{text:"Enumerator",url:"globals_eval.html"},
{text:"Macros",url:"globals_defs.html",children:[
{text:"a",url:"globals_defs.html#index_a"},
{text:"c",url:"globals_defs_c.html#index_c"},
{text:"f",url:"globals_defs_f.html#index_f"},
{text:"i",url:"globals_defs_i.html#index_i"},
{text:"l",url:"globals_defs_l.html#index_l"},
{text:"m",url:"globals_defs_m.html#index_m"},
{text:"n",url:"globals_defs_n.html#index_n"},
{text:"p",url:"globals_defs_p.html#index_p"},
{text:"t",url:"globals_defs_t.html#index_t"},
{text:"u",url:"globals_defs_u.html#index_u"},
{text:"x",url:"globals_defs_x.html#index_x"}]}]}]}]}
